package com.mall.member.controller;

import com.mall.member.domain.dto.MemberStatisticsInfoDto;
import com.mall.member.domain.entity.MemberStatisticsInfo;
import com.mall.member.domain.vo.MemberStatisticsInfoVo;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.RequiredArgsConstructor;
import com.mall.member.service.MemberStatisticsInfoService;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.common.domain.vo.result.Result;
import com.mall.common.domain.vo.result.ResultCodeEnum;

import java.util.List;

/**
 * <p>
 * 会员统计信息 前端控制器
 * </p>
 *
 * @author Bunny
 * @since 2025-07-05 19:30:06
 */
@Tag(name = "会员统计信息", description = "会员统计信息相关接口")
@RestController
@RequestMapping("/api/member/member-statistics-info")
@RequiredArgsConstructor
public class MemberStatisticsInfoController {

    private final MemberStatisticsInfoService memberStatisticsInfoService;

    @Operation(summary = "分页查询会员统计信息", description = "分页会员统计信息")
    @GetMapping("{page}/{limit}")
    public Result<PageResult<MemberStatisticsInfoVo>> getMemberStatisticsInfoPage(
            @Parameter(name = "page", description = "当前页", required = true)
            @PathVariable("page") Integer page,
            @Parameter(name = "limit", description = "每页记录数", required = true)
            @PathVariable("limit") Integer limit,
            MemberStatisticsInfoDto dto) {
        Page<MemberStatisticsInfo> pageParams = new Page<>(page, limit);
        PageResult<MemberStatisticsInfoVo> pageResult = memberStatisticsInfoService.getMemberStatisticsInfoPage(pageParams, dto);
        return Result.success(pageResult);
    }

    @Operation(summary = "添加会员统计信息", description = "添加会员统计信息")
    @PostMapping()
    public Result<String> addMemberStatisticsInfo(@Valid @RequestBody MemberStatisticsInfoDto dto) {
            memberStatisticsInfoService.addMemberStatisticsInfo(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @Operation(summary = "更新会员统计信息", description = "更新会员统计信息")
    @PutMapping()
    public Result<String> updateMemberStatisticsInfo(@Valid @RequestBody MemberStatisticsInfoDto dto) {
            memberStatisticsInfoService.updateMemberStatisticsInfo(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @Operation(summary = "删除会员统计信息", description = "删除会员统计信息")
    @DeleteMapping()
    public Result<String> deleteMemberStatisticsInfo(@RequestBody List<Long> ids) {
            memberStatisticsInfoService.deleteMemberStatisticsInfo(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }
}