package com.mall.member.service.impl;

import com.mall.member.mapper.MemberCollectSpuMapper;
import com.mall.member.service.MemberCollectSpuService;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.mall.member.service.MemberCollectSpuService;
import com.mall.member.domain.dto.MemberCollectSpuDto;
import com.mall.member.domain.entity.MemberCollectSpu;
import com.mall.member.domain.vo.MemberCollectSpuVo;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.common.domain.vo.result.Result;
import com.mall.common.domain.vo.result.ResultCodeEnum;

import java.util.List;

/**
 * <p>
 * 会员收藏的商品 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-05 19:30:06
 */
@Service
@Transactional
public class MemberCollectSpuServiceImpl extends ServiceImpl<MemberCollectSpuMapper, MemberCollectSpu> implements MemberCollectSpuService {

    /**
     * * 会员收藏的商品 服务实现类
     *
     * @param pageParams 会员收藏的商品分页查询page对象
     * @param dto        会员收藏的商品分页查询对象
     * @return 查询分页会员收藏的商品返回对象
     */
    @Override
    public PageResult<MemberCollectSpuVo> getMemberCollectSpuPage(Page<MemberCollectSpu> pageParams, MemberCollectSpuDto dto) {
        IPage<MemberCollectSpuVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<MemberCollectSpuVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加会员收藏的商品
     *
     * @param dto 会员收藏的商品添加
     */
    @Override
    public void addMemberCollectSpu(MemberCollectSpuDto dto) {
        MemberCollectSpu memberCollectSpu =new MemberCollectSpu();
        BeanUtils.copyProperties(dto, memberCollectSpu);
        save(memberCollectSpu);
    }

    /**
     * 更新会员收藏的商品
     *
     * @param dto 会员收藏的商品更新
     */
    @Override
    public void updateMemberCollectSpu(MemberCollectSpuDto dto) {
        MemberCollectSpu memberCollectSpu =new MemberCollectSpu();
        BeanUtils.copyProperties(dto, memberCollectSpu);
        updateById(memberCollectSpu);
    }

    /**
     * 删除|批量删除会员收藏的商品
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteMemberCollectSpu(List<Long> ids) {
        removeByIds(ids);
    }
}