package com.mall.order.service.impl;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.order.domain.dto.OrderReturnApplyDto;
import com.mall.order.domain.entity.OrderReturnApply;
import com.mall.order.domain.vo.OrderReturnApplyVo;
import com.mall.order.mapper.OrderReturnApplyMapper;
import com.mall.order.service.OrderReturnApplyService;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * 订单退货申请 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-05 18:54:06
 */
@Service
@Transactional
public class OrderReturnApplyServiceImpl extends ServiceImpl<OrderReturnApplyMapper, OrderReturnApply> implements OrderReturnApplyService {

    /**
     * * 订单退货申请 服务实现类
     *
     * @param pageParams 订单退货申请分页查询page对象
     * @param dto        订单退货申请分页查询对象
     * @return 查询分页订单退货申请返回对象
     */
    @Override
    public PageResult<OrderReturnApplyVo> getOrderReturnApplyPage(Page<OrderReturnApply> pageParams, OrderReturnApplyDto dto) {
        IPage<OrderReturnApplyVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<OrderReturnApplyVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加订单退货申请
     *
     * @param dto 订单退货申请添加
     */
    @Override
    public void addOrderReturnApply(OrderReturnApplyDto dto) {
        OrderReturnApply orderReturnApply = new OrderReturnApply();
        BeanUtils.copyProperties(dto, orderReturnApply);
        save(orderReturnApply);
    }

    /**
     * 更新订单退货申请
     *
     * @param dto 订单退货申请更新
     */
    @Override
    public void updateOrderReturnApply(OrderReturnApplyDto dto) {
        OrderReturnApply orderReturnApply = new OrderReturnApply();
        BeanUtils.copyProperties(dto, orderReturnApply);
        updateById(orderReturnApply);
    }

    /**
     * 删除|批量删除订单退货申请
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteOrderReturnApply(List<Long> ids) {
        removeByIds(ids);
    }
}