package com.mall.order.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.order.domain.dto.OrderSettingDto;
import com.mall.order.domain.entity.OrderSetting;
import com.mall.order.domain.vo.OrderSettingVo;
import com.mall.order.mapper.OrderSettingMapper;
import com.mall.order.service.OrderSettingService;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * 订单配置信息 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-05 18:54:06
 */
@Service
@Transactional
public class OrderSettingServiceImpl extends ServiceImpl<OrderSettingMapper, OrderSetting> implements OrderSettingService {

    /**
     * * 订单配置信息 服务实现类
     *
     * @param pageParams 订单配置信息分页查询page对象
     * @param dto        订单配置信息分页查询对象
     * @return 查询分页订单配置信息返回对象
     */
    @Override
    public PageResult<OrderSettingVo> getOrderSettingPage(Page<OrderSetting> pageParams, OrderSettingDto dto) {
        IPage<OrderSettingVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<OrderSettingVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加订单配置信息
     *
     * @param dto 订单配置信息添加
     */
    @Override
    public void addOrderSetting(OrderSettingDto dto) {
        OrderSetting orderSetting = new OrderSetting();
        BeanUtils.copyProperties(dto, orderSetting);
        save(orderSetting);
    }

    /**
     * 更新订单配置信息
     *
     * @param dto 订单配置信息更新
     */
    @Override
    public void updateOrderSetting(OrderSettingDto dto) {
        OrderSetting orderSetting = new OrderSetting();
        BeanUtils.copyProperties(dto, orderSetting);
        updateById(orderSetting);
    }

    /**
     * 删除|批量删除订单配置信息
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteOrderSetting(List<Long> ids) {
        removeByIds(ids);
    }
}