package com.mall.order.service.impl;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.order.domain.dto.PaymentInfoDto;
import com.mall.order.domain.entity.PaymentInfo;
import com.mall.order.domain.vo.PaymentInfoVo;
import com.mall.order.mapper.PaymentInfoMapper;
import com.mall.order.service.PaymentInfoService;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * 支付信息表 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-05 18:54:06
 */
@Service
@Transactional
public class PaymentInfoServiceImpl extends ServiceImpl<PaymentInfoMapper, PaymentInfo> implements PaymentInfoService {

    /**
     * * 支付信息表 服务实现类
     *
     * @param pageParams 支付信息表分页查询page对象
     * @param dto        支付信息表分页查询对象
     * @return 查询分页支付信息表返回对象
     */
    @Override
    public PageResult<PaymentInfoVo> getPaymentInfoPage(Page<PaymentInfo> pageParams, PaymentInfoDto dto) {
        IPage<PaymentInfoVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<PaymentInfoVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加支付信息表
     *
     * @param dto 支付信息表添加
     */
    @Override
    public void addPaymentInfo(PaymentInfoDto dto) {
        PaymentInfo paymentInfo = new PaymentInfo();
        BeanUtils.copyProperties(dto, paymentInfo);
        save(paymentInfo);
    }

    /**
     * 更新支付信息表
     *
     * @param dto 支付信息表更新
     */
    @Override
    public void updatePaymentInfo(PaymentInfoDto dto) {
        PaymentInfo paymentInfo = new PaymentInfo();
        BeanUtils.copyProperties(dto, paymentInfo);
        updateById(paymentInfo);
    }

    /**
     * 删除|批量删除支付信息表
     *
     * @param ids 删除id列表
     */
    @Override
    public void deletePaymentInfo(List<Long> ids) {
        removeByIds(ids);
    }
}