package com.mall.product.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.common.domain.vo.result.Result;
import com.mall.common.domain.vo.result.ResultCodeEnum;
import com.mall.product.domain.dto.BrandDto;
import com.mall.product.domain.entity.Brand;
import com.mall.product.domain.vo.BrandVo;
import com.mall.product.service.BrandService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 品牌 前端控制器
 * </p>
 *
 * @author Bunny
 * @since 2025-07-04 15:19:19
 */
@Tag(name = "品牌", description = "品牌相关接口")
@RestController
@RequestMapping("/api/product/brand")
@RequiredArgsConstructor
public class BrandController {

    private final BrandService brandService;

    @Operation(summary = "分页查询品牌", description = "分页品牌")
    @GetMapping("{page}/{limit}")
    public Result<PageResult<BrandVo>> getBrandPage(
            @Parameter(name = "page", description = "当前页", required = true)
            @PathVariable("page") Integer page,
            @Parameter(name = "limit", description = "每页记录数", required = true)
            @PathVariable("limit") Integer limit,
            BrandDto dto) {
        Page<Brand> pageParams = new Page<>(page, limit);
        PageResult<BrandVo> pageResult = brandService.getBrandPage(pageParams, dto);
        return Result.success(pageResult);
    }

    @Operation(summary = "添加品牌", description = "添加品牌")
    @PostMapping()
    public Result<String> addBrand(@Valid @RequestBody BrandDto dto) {
        brandService.addBrand(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @Operation(summary = "更新品牌", description = "更新品牌")
    @PutMapping()
    public Result<String> updateBrand(@Valid @RequestBody BrandDto dto) {
        brandService.updateBrand(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @Operation(summary = "删除品牌", description = "删除品牌")
    @DeleteMapping()
    public Result<String> deleteBrand(@RequestBody List<Long> ids) {
        brandService.deleteBrand(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }
}