package com.mall.product.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.common.domain.vo.result.Result;
import com.mall.common.domain.vo.result.ResultCodeEnum;
import com.mall.product.domain.dto.SpuInfoDto;
import com.mall.product.domain.entity.SpuInfo;
import com.mall.product.domain.vo.SpuInfoVo;
import com.mall.product.service.SpuInfoService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * spu信息 前端控制器
 * </p>
 *
 * @author Bunny
 * @since 2025-07-04 15:19:19
 */
@Tag(name = "spu信息", description = "spu信息相关接口")
@RestController
@RequestMapping("/api/product/spuInfo")
@RequiredArgsConstructor
public class SpuInfoController {

    private final SpuInfoService spuInfoService;

    @Operation(summary = "分页查询spu信息", description = "分页spu信息")
    @GetMapping("{page}/{limit}")
    public Result<PageResult<SpuInfoVo>> getSpuInfoPage(
            @Parameter(name = "page", description = "当前页", required = true)
            @PathVariable("page") Integer page,
            @Parameter(name = "limit", description = "每页记录数", required = true)
            @PathVariable("limit") Integer limit,
            SpuInfoDto dto) {
        Page<SpuInfo> pageParams = new Page<>(page, limit);
        PageResult<SpuInfoVo> pageResult = spuInfoService.getSpuInfoPage(pageParams, dto);
        return Result.success(pageResult);
    }

    @Operation(summary = "添加spu信息", description = "添加spu信息")
    @PostMapping()
    public Result<String> addSpuInfo(@Valid @RequestBody SpuInfoDto dto) {
        spuInfoService.addSpuInfo(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @Operation(summary = "更新spu信息", description = "更新spu信息")
    @PutMapping()
    public Result<String> updateSpuInfo(@Valid @RequestBody SpuInfoDto dto) {
        spuInfoService.updateSpuInfo(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @Operation(summary = "删除spu信息", description = "删除spu信息")
    @DeleteMapping()
    public Result<String> deleteSpuInfo(@RequestBody List<Long> ids) {
        spuInfoService.deleteSpuInfo(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }
}