package com.mall.product.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.product.domain.dto.CategoryDto;
import com.mall.product.domain.entity.Category;
import com.mall.product.domain.vo.CategoryVo;
import com.mall.product.mapper.CategoryMapper;
import com.mall.product.service.CategoryService;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * 商品三级分类 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-04 14:05:53
 */
@Service
@Transactional
public class CategoryServiceImpl extends ServiceImpl<CategoryMapper, Category> implements CategoryService {

    /**
     * * 商品三级分类 服务实现类
     *
     * @param pageParams 商品三级分类分页查询page对象
     * @param dto        商品三级分类分页查询对象
     * @return 查询分页商品三级分类返回对象
     */
    @Override
    public PageResult<CategoryVo> getCategoryPage(Page<Category> pageParams, CategoryDto dto) {
        IPage<CategoryVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<CategoryVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加商品三级分类
     *
     * @param dto 商品三级分类添加
     */
    @Override
    public void addCategory(CategoryDto dto) {
        Category category = new Category();
        BeanUtils.copyProperties(dto, category);
        save(category);
    }

    /**
     * 更新商品三级分类
     *
     * @param dto 商品三级分类更新
     */
    @Override
    public void updateCategory(CategoryDto dto) {
        Category category = new Category();
        BeanUtils.copyProperties(dto, category);
        updateById(category);
    }

    /**
     * 删除|批量删除商品三级分类
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteCategory(List<Long> ids) {
        removeByIds(ids);
    }
}