package com.mall.product.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.product.domain.dto.ProductAttrValueDto;
import com.mall.product.domain.entity.ProductAttrValue;
import com.mall.product.domain.vo.ProductAttrValueVo;
import com.mall.product.mapper.ProductAttrValueMapper;
import com.mall.product.service.ProductAttrValueService;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * spu属性值 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-04 14:05:53
 */
@Service
@Transactional
public class ProductAttrValueServiceImpl extends ServiceImpl<ProductAttrValueMapper, ProductAttrValue> implements ProductAttrValueService {

    /**
     * * spu属性值 服务实现类
     *
     * @param pageParams spu属性值分页查询page对象
     * @param dto        spu属性值分页查询对象
     * @return 查询分页spu属性值返回对象
     */
    @Override
    public PageResult<ProductAttrValueVo> getProductAttrValuePage(Page<ProductAttrValue> pageParams, ProductAttrValueDto dto) {
        IPage<ProductAttrValueVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<ProductAttrValueVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加spu属性值
     *
     * @param dto spu属性值添加
     */
    @Override
    public void addProductAttrValue(ProductAttrValueDto dto) {
        ProductAttrValue productAttrValue = new ProductAttrValue();
        BeanUtils.copyProperties(dto, productAttrValue);
        save(productAttrValue);
    }

    /**
     * 更新spu属性值
     *
     * @param dto spu属性值更新
     */
    @Override
    public void updateProductAttrValue(ProductAttrValueDto dto) {
        ProductAttrValue productAttrValue = new ProductAttrValue();
        BeanUtils.copyProperties(dto, productAttrValue);
        updateById(productAttrValue);
    }

    /**
     * 删除|批量删除spu属性值
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteProductAttrValue(List<Long> ids) {
        removeByIds(ids);
    }
}