package com.mall.product.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.product.domain.dto.SkuSaleAttrValueDto;
import com.mall.product.domain.entity.SkuSaleAttrValue;
import com.mall.product.domain.vo.SkuSaleAttrValueVo;
import com.mall.product.mapper.SkuSaleAttrValueMapper;
import com.mall.product.service.SkuSaleAttrValueService;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * sku销售属性&值 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-04 14:05:53
 */
@Service
@Transactional
public class SkuSaleAttrValueServiceImpl extends ServiceImpl<SkuSaleAttrValueMapper, SkuSaleAttrValue> implements SkuSaleAttrValueService {

    /**
     * * sku销售属性&值 服务实现类
     *
     * @param pageParams sku销售属性&值分页查询page对象
     * @param dto        sku销售属性&值分页查询对象
     * @return 查询分页sku销售属性&值返回对象
     */
    @Override
    public PageResult<SkuSaleAttrValueVo> getSkuSaleAttrValuePage(Page<SkuSaleAttrValue> pageParams, SkuSaleAttrValueDto dto) {
        IPage<SkuSaleAttrValueVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<SkuSaleAttrValueVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加sku销售属性&值
     *
     * @param dto sku销售属性&值添加
     */
    @Override
    public void addSkuSaleAttrValue(SkuSaleAttrValueDto dto) {
        SkuSaleAttrValue skuSaleAttrValue = new SkuSaleAttrValue();
        BeanUtils.copyProperties(dto, skuSaleAttrValue);
        save(skuSaleAttrValue);
    }

    /**
     * 更新sku销售属性&值
     *
     * @param dto sku销售属性&值更新
     */
    @Override
    public void updateSkuSaleAttrValue(SkuSaleAttrValueDto dto) {
        SkuSaleAttrValue skuSaleAttrValue = new SkuSaleAttrValue();
        BeanUtils.copyProperties(dto, skuSaleAttrValue);
        updateById(skuSaleAttrValue);
    }

    /**
     * 删除|批量删除sku销售属性&值
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteSkuSaleAttrValue(List<Long> ids) {
        removeByIds(ids);
    }
}