package com.mall.product.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.product.domain.dto.SpuCommentDto;
import com.mall.product.domain.entity.SpuComment;
import com.mall.product.domain.vo.SpuCommentVo;
import com.mall.product.mapper.SpuCommentMapper;
import com.mall.product.service.SpuCommentService;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * 商品评价 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-04 14:05:53
 */
@Service
@Transactional
public class SpuCommentServiceImpl extends ServiceImpl<SpuCommentMapper, SpuComment> implements SpuCommentService {

    /**
     * * 商品评价 服务实现类
     *
     * @param pageParams 商品评价分页查询page对象
     * @param dto        商品评价分页查询对象
     * @return 查询分页商品评价返回对象
     */
    @Override
    public PageResult<SpuCommentVo> getSpuCommentPage(Page<SpuComment> pageParams, SpuCommentDto dto) {
        IPage<SpuCommentVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<SpuCommentVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加商品评价
     *
     * @param dto 商品评价添加
     */
    @Override
    public void addSpuComment(SpuCommentDto dto) {
        SpuComment spuComment = new SpuComment();
        BeanUtils.copyProperties(dto, spuComment);
        save(spuComment);
    }

    /**
     * 更新商品评价
     *
     * @param dto 商品评价更新
     */
    @Override
    public void updateSpuComment(SpuCommentDto dto) {
        SpuComment spuComment = new SpuComment();
        BeanUtils.copyProperties(dto, spuComment);
        updateById(spuComment);
    }

    /**
     * 删除|批量删除商品评价
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteSpuComment(List<Long> ids) {
        removeByIds(ids);
    }
}