package com.mall.product.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.product.domain.dto.SpuInfoDto;
import com.mall.product.domain.entity.SpuInfo;
import com.mall.product.domain.vo.SpuInfoVo;
import com.mall.product.mapper.SpuInfoMapper;
import com.mall.product.service.SpuInfoService;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * spu信息 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-04 14:05:53
 */
@Service
@Transactional
public class SpuInfoServiceImpl extends ServiceImpl<SpuInfoMapper, SpuInfo> implements SpuInfoService {

    /**
     * * spu信息 服务实现类
     *
     * @param pageParams spu信息分页查询page对象
     * @param dto        spu信息分页查询对象
     * @return 查询分页spu信息返回对象
     */
    @Override
    public PageResult<SpuInfoVo> getSpuInfoPage(Page<SpuInfo> pageParams, SpuInfoDto dto) {
        IPage<SpuInfoVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<SpuInfoVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加spu信息
     *
     * @param dto spu信息添加
     */
    @Override
    public void addSpuInfo(SpuInfoDto dto) {
        SpuInfo spuInfo = new SpuInfo();
        BeanUtils.copyProperties(dto, spuInfo);
        save(spuInfo);
    }

    /**
     * 更新spu信息
     *
     * @param dto spu信息更新
     */
    @Override
    public void updateSpuInfo(SpuInfoDto dto) {
        SpuInfo spuInfo = new SpuInfo();
        BeanUtils.copyProperties(dto, spuInfo);
        updateById(spuInfo);
    }

    /**
     * 删除|批量删除spu信息
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteSpuInfo(List<Long> ids) {
        removeByIds(ids);
    }
}